#[non_exhaustive]pub enum Request<'a> {
Offer {
mime_type: String,
},
Destroy,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Offer
add an offered MIME type
This request adds a MIME type to the set of MIME types advertised to targets. Can be called several times to offer multiple types.
Calling this after ext_data_control_device.set_selection is a protocol error.
Destroy
destroy this source
Destroys the data source object.
This is a destructor, once sent this object cannot be used any longer.
Implementations